#ifndef PPC405EP_LCD
#define PPC405EP_LCD
//
// Header file for PPC 405EP LCD 
//

#include <asm-generic/errno-base.h>		// for driver return error code

int lcdClear(int fd);
int lcdBackLight(int fd, int on);
int lcdCmd(int fd, char cmd);
int lcdData(int fd, char data);
int lcdHome(int fd);
int lcdSetCursorPosi(int fd, char row, char col);
int lcdCursorOn(int fd, int on);

int lcdWriteChar(int fd, char cV);
int lcdWriteStr(int fd, char *str);


// here are for ioctl()
#define MAGIC_NUMBER '6'
// This magic number is in conflict with Intel IA32 microcode update driver. See
// linux/documentation/ioctl-number.txt:
// '6'	00-10	<asm-i386/processor.h>	Intel IA32 microcode update driver
//					<mailto:tigran@veritas.com>
//
// However, PPC architecture will not use IA32 stuff, I hope.
//

#define IOCTRL_PPC405EP_LCD_SET_SIZE	_IOW(MAGIC_NUMBER,  0, int)
// set LCD size - rows << 8 + columns, will be used for seek()
// sample: 0x210 means 2 rows and 16 columns
// rows - 1..10, cols - 8..80

#define IOCTRL_PPC405EP_LCD_GET_SIZE	_IOR(MAGIC_NUMBER,  1, int *)
// get LCD size - row = >> 8, columns = & 0xff, see set size

#define IOCTRL_PPC405EP_LCD_CMD			_IOW(MAGIC_NUMBER,  2, char)
// write to LCD command byte, it can be used to "build" init sequence
// NOTE: when writing 1, clear LCD, lcd requres 2 ms wait. Others, 50 us

#define IOCTRL_PPC405EP_LCD_DATA		_IOWR(MAGIC_NUMBER, 3, char)
// read lcd data, input command, return data
// it could return EPERM, such as command = 1, or not implemented yet.

#define IOCTRL_PPC405EP_LCD_SET_LIGHT	_IOW(MAGIC_NUMBER,  4, char)
// turn back light on/off

#endif // PPC405EP_LCD
